Archan
======

.. image:: https://travis-ci.org/Pawamoy/archan.svg
    :target: https://travis-ci.org/Pawamoy/archan
    :alt: Build Status

.. image:: https://readthedocs.org/projects/archan/badge/?version=latest
    :target: https://readthedocs.org/projects/archan/?badge=latest
    :alt: Documentation Status

.. image:: https://coveralls.io/repos/Pawamoy/archan/badge.svg
    :target: https://coveralls.io/r/Pawamoy/archan
    :alt: Coverage Status

*Contents coming later*
